use crate::prelude::*;
use log::error;

/// Gets the master password, deletes the accounts and the master password from DB.
/// Although it doesn't use the master password, we get it to be sure that it's the user who used that command
#[inline]
async fn get_master_pass(
    bot: Throttle<Bot>,
    msg: Message,
    db: Pool,
    dialogue: MainDialogue,
    mut ids: MessageIds,
    _: String,
) -> crate::Result<()> {
    dialogue.exit().await?;
    let user_id = msg.from().ok_or(NoUserInfo)?.id.0;
    let mut txn = db.begin().await?;
    let result = (
        Account::delete_all(user_id, &mut *txn).await,
        MasterPass::remove(user_id, &mut *txn).await,
    );
    let text = match result {
        (Ok(()), Ok(())) => {
            txn.commit().await?;
            "Everything was deleted"
        }
        (Err(err), _) | (_, Err(err)) => {
            error!("{}", crate::Error::from(err));
            txn.rollback().await?;
            "Something went wrong. Try again later"
        }
    };
    ids.alter_message(&bot, text, deletion_markup(), None)
        .await?;
    Ok(())
}

first_handler!(
    delete_all,
    "Send master password to delete EVERYTHING.\nTHIS ACTION IS IRREVERSIBLE",
    State::GetMasterPass,
    get_master_pass
);
